@@ -47,8 +47,8 @@ class MySQL_Helper:
 				if (x[0] == self.db):
 					self.sw.echo ("Found Pre-Existing Database [" + x[0] + "]")
 					return True
-			mycursor.execute ("CREATE DATABASE " + self.db)
-			self.sw.echo ("Created Database [" + self.db + "]")
+			mycursor.execute ("CREATE DATABASE " + self.db + " DEFAULT CHARACTER SET utf8 COLLATE utf8_unicode_ci")
+			self.sw.echo ("Created Database [" + self.db + "] DEFAULT CHARACTER SET utf8 COLLATE utf8_unicode_ci")
 
 	def table_exists (self, table_name):
 		for tabname in self.tables:
